@@ -1,44 +1,13 @@
 /*
- * Copyright (c) Cristian Gafton <gafton@sorosis.ro>, 1997.
- *                                              All rights reserved
- * Copyright (C) Francesco P. Lovergine <francesco@lovergine.com>, 1999-2001.
+ * Copyright (C) 1999-2002 Francesco P. Lovergine. 
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, and the entire permission notice in its entirety,
- *    including the disclaimer of warranties.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior
- *    written permission.
- * 4. Any modification to the program, as well as redistribution in binary
- *    or derived source form must be advertised to the author.
- *
- * ALTERNATIVELY, this product may be distributed under the terms of
- * the GNU Public License, in which case the provisions of the GPL are
- * required INSTEAD OF the above restrictions.  (This clause is
- * necessary due to a potential bad interaction between the GPL and
- * the restrictions contained in a BSD-style copyright.)
- *
- * THIS SOFTWARE IS PROVIDED `AS IS'' AND ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
- * OF THE POSSIBILITY OF SUCH DAMAGE.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms stated in the LICENSE file which should be
+ * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: extens.c,v 1.7 2001/08/21 12:50:46 kiavik Exp $";
+static char rcsid[] = "$Id: extens.c,v 1.9 2004/07/01 13:57:55 flovergine Exp $";
 
 #include	"yard.h"
 #include	"global.h"
@@ -181,7 +150,7 @@ int check_maxtime(char *user, const int hours, const int kind)
  *
  *   Cristian Gafton - <gafton@sorosis.ro>
  *
- *   Corrected a lot of memory leaks - <francesco@lovergine.com>
+ *   Corrected a lot of memory leaks - <francesco@yardradius.org>
  */ 
 int clean_user_stats(void)
 {
