@@ -1,82 +1,13 @@
-/***********************************************************************
-
-RADIUS
-Remote Authentication Dial In User Service
-
-Lucent Technologies Remote Access
-4464 Willow Road
-Pleasanton, CA   94588
-
-Copyright 1992-1999 Lucent Technologies Inc.  All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are
-met:
-
-    * Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-
-    * Redistributions in binary form must reproduce the above
-      copyright notice, this list of conditions and the following
-      disclaimer in the documentation and/or other materials provided
-      with the distribution.
-
-    * All advertising materials mentioning features or use of this
-      software must display the following acknowledgement:
-
-    This product includes software developed by Lucent
-    Technologies and its contributors.
-
-    * Neither the name of the copyright holder nor the names of its
-      contributors may be used to endorse or promote products derived
-      from this software without specific prior written permission.
-
-This software is provided by the copyright holders and contributors
-``as is'' and any express or implied warranties, including, but not
-limited to, the implied warranties of merchantability and fitness for a
-particular purpose are disclaimed. In no event shall the copyright
-holder or contributors be liable for any direct, indirect, incidental,
-special, exemplary, or consequential damages (including, but not
-limited to, procurement of substitute goods or services; loss of use,
-data, or profits; or business interruption) however caused and on any
-theory of liability, whether in contract, strict liability, or tort
-(including negligence or otherwise) arising in any way out of the use
-of this software, even if advised of the possibility of such damage.
-
-************************************************************************/
-
 /*
-  * Copyright (C) 1999-2002 Francesco P. Lovergine. All rights reserved.
-  *
-  * Redistribution and use in source and binary forms, with or without
-  * modification, are permitted provided that the following conditions
-  * are met:
-  * 1. Redistributions of source code must retain the above copyright
-  *    notice, and the entire permission notice in its entirety,
-  *    including the disclaimer of warranties.
-  * 2. Redistributions in binary form must reproduce the above copyright
-  *    notice, this list of conditions and the following disclaimer in the
-  *    documentation and/or other materials provided with the distribution.
-  * 3. The name of the author may not be used to endorse or promote
-  *    products derived from this software without specific prior
-  *    written permission.
-  * 4. Any modification to the program, as well as redistribution in binary
-  *    or derived source form must be advertised to the author.
-  *
-  * THIS SOFTWARE IS PROVIDED `AS IS'' AND ANY EXPRESS OR IMPLIED
-  * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-  * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-  * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
-  * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-  * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-  * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
-  * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
-  * OF THE POSSIBILITY OF SUCH DAMAGE.
-  */
+ * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms stated in the LICENSE file which should be
+ * enclosed with sources.
+ */
 
-static char rcsid[] = "$Id: radiusd.c,v 1.7 2002/01/21 09:14:56 kiavik Exp $";
+static char rcsid[] = "$Id: radiusd.c,v 1.9 2002/03/05 19:17:57 kiavik Exp $";
 
 
 #define __MAIN__
