@@ -1,45 +1,13 @@
 /*
- * Copyright (c) Cristian Gafton <gafton@sorosis.ro>, 1997.
- *                                              All rights reserved
+ * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * All rights reserved.
  *
- * Copyright (c) Francesco P. Lovergine <francesco@lovergine.com>, 1999-2002.
- *                                              All rights reserved
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, and the entire permission notice in its entirety,
- *    including the disclaimer of warranties.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior
- *    written permission.
- * 4. Any modification to the program, as well as redistribution in binary
- *    or derived source form must be advertised to the author.
- *
- * ALTERNATIVELY, this product may be distributed under the terms of
- * the GNU Public License, in which case the provisions of the GPL are
- * required INSTEAD OF the above restrictions.  (This clause is
- * necessary due to a potential bad interaction between the GPL and
- * the restrictions contained in a BSD-style copyright.)
- *
- * THIS SOFTWARE IS PROVIDED `AS IS'' AND ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
- * OF THE POSSIBILITY OF SUCH DAMAGE.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms stated in the LICENSE file which should be
+ * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: radlist.c,v 1.5 2002/01/21 09:08:54 kiavik Exp $";
+static char rcsid[] = "$Id: radlist.c,v 1.8 2003/07/08 13:20:42 kiavik Exp $";
     
 #define __MAIN__
 
@@ -247,7 +215,7 @@ static void error(char *fmt,...)
   va_start(arg,fmt);
   fprintf( stderr,"%s: ",progname );
   print_error(fmt,arg);
-  va_end(fmt);
+  va_end(arg);
 }
 
 static int parse_width(char **format)
